package com.example.resource.clue.convert.service;

import cn.hutool.core.codec.Base64;
import cn.hutool.core.util.IdUtil;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.example.resource.clue.convert.bo.CusInfoJsonBo;
import com.example.resource.clue.convert.bo.CusinfoBodyBo;
import com.example.resource.clue.convert.bo.CusinfoFiledBo;
import com.example.resource.clue.convert.bo.DataCenterPushClueBo;
import com.example.resource.clue.convert.config.ResourceClueConveryConfig;
import com.example.resource.clue.convert.utils.AESUtils;
import com.example.resource.clue.convert.utils.LinkUtil;
import com.example.resource.clue.convert.utils.MD5;
import com.example.resource.clue.convert.utils.PhoneAESUtil;
import com.example.resource.clue.convert.vo.R;
import com.example.resource.clue.convert.vo.ReqHuoKeVo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author ：fxl
 * @date ：Created in 2023/6/13 10:03
 * @description：
 */
@Slf4j
@Service
public class DataCenterPushClueService {

    @Autowired
    private ResourceClueConveryConfig clueConveryConfig;

    /**
     * 数据中台推送的线索
     * @param dataCenterPushClueBo
     * @return
     */
    public R pushClue(DataCenterPushClueBo dataCenterPushClueBo) {
//        DataCenterPushClueBo centerPushClueBo = resourceClueConvery(dataCenterPushClueBo);
        String extid = IdUtil.getSnowflakeNextIdStr();
        ReqHuoKeVo reqHuoKeVo = ReqHuoKeVo.builder()
                .appName(dataCenterPushClueBo.getCusName())
                .appIdno(dataCenterPushClueBo.getIdNo())
                .appMobile(dataCenterPushClueBo.getCusId())
                .extId(extid)
                .product(clueConveryConfig.getProduct()) // 暂时为空
                .city("").cityCode("")
                .sex(dataCenterPushClueBo.getSex())
                .age("")
                .birthday(dataCenterPushClueBo.getBirthday())
                .province("").incomeMonth("").wagesType("").loan("").room("").car("").socialSecurity("").accumulationFund("").credit("").policy("").wld("").ip("").ipAddress("").creatTime("")
                .remark1(clueConveryConfig.getRemark1())
                .remark2(clueConveryConfig.getRemark2())
                .remark4(clueConveryConfig.getRemark4())
                .remark5("")
                .kstype(clueConveryConfig.getKstype())
                .userAgent("").build();
        // 解析结构化
        handleCusinfo(reqHuoKeVo,dataCenterPushClueBo);
        log.info("请求获客明文: {}",JSON.toJSONString(reqHuoKeVo));
        Map<String, Object> pMap = new HashMap<String, Object>();
        String data = "";
        try {
            data = AESUtils.Encrypt(
                    JSON.toJSONString(reqHuoKeVo),
                    AESUtils.parseHexStr2Byte(clueConveryConfig.getEncryKey()),
                    AESUtils.parseHexStr2Byte(clueConveryConfig.getEncryLv())
            );
        } catch (Exception e) {
            log.info("加密参数报错: {}, 堆栈: {}",e.getMessage(),e.getStackTrace());
        }
        pMap.put("inid", clueConveryConfig.getInid());
        pMap.put("uid", clueConveryConfig.getUid());
        pMap.put("timestamp", String.valueOf(System.currentTimeMillis()));
        String id = IdUtil.objectId();
        String resId = id.toUpperCase();
        pMap.put("nonce", resId);
        pMap.put("data", data);
        String linkStr = LinkUtil.getLinkString(pMap);

        // 需要签名的字符串+密钥// MD5加密// 编码格式UTF-8
        String signature = MD5.sign(linkStr, clueConveryConfig.getSignKey(), "UTF-8");
        pMap.put("signature", signature);
        log.info("请求获客报文: {}",JSON.toJSONString(pMap));
        String resultJson = HttpUtil.post(clueConveryConfig.getHkurl(), pMap);
        log.info("请求获客返回: {}, uuid: {}", resultJson,dataCenterPushClueBo.getCusId());
        return R.ok();
    }

    /**
     * 处理结构化
     * @param reqHuoKeVo
     * @param centerPushClueBo
     */
    private void handleCusinfo(ReqHuoKeVo reqHuoKeVo, DataCenterPushClueBo centerPushClueBo) {
        String cusinfoJson = Base64.decodeStr(centerPushClueBo.getCusInfo());
        CusInfoJsonBo cusInfoJsonBo = JSON.parseObject(cusinfoJson, CusInfoJsonBo.class);
        List<CusinfoBodyBo> pData = cusInfoJsonBo.getPData();
        if(pData != null && pData.size() > 0){
            List<CusinfoFiledBo> pvalue = pData.get(0).getValue();
            if(pvalue != null && pvalue.size() > 0){
                for (CusinfoFiledBo cusinfoFiledBo : pvalue) {
                    if("policyGmtCreated".equals(cusinfoFiledBo.getField())){
                        reqHuoKeVo.setRemark3("百万医疗承保时间：" + cusinfoFiledBo.getValue());
                    }
                }
            }
        }
    }

    /**
     * 请求资源方接口获取明文
     * @param dataCenterPushClueBo
     * @return
     */
    private DataCenterPushClueBo resourceClueConvery(DataCenterPushClueBo dataCenterPushClueBo) {
        String url = clueConveryConfig.getXbUrl() + "?inDate=20221116&source=KSAI&cid=274302&cusid="+dataCenterPushClueBo.getCusId();
        log.info("获取明文请求地址： {}, 请求key：{}, lv: {}",url,clueConveryConfig.getXbKey(),clueConveryConfig.getXbLv());
        String body = HttpUtil.get(url);
        log.info("小宝明文响应结果： {} ",body);
        JSONObject jsonObject = JSON.parseObject(body);
        if("1".equals(jsonObject.getString("code"))){
            JSONObject data = jsonObject.getJSONObject("data");
            String dataJson = PhoneAESUtil.decode(data.getString("data"), clueConveryConfig.getXbKey(), clueConveryConfig.getXbLv());//利用key解密
            JSONObject cusObject = JSON.parseObject(dataJson);
            dataCenterPushClueBo.setCusName(cusObject.getString("name"));
            dataCenterPushClueBo.setIdNo(cusObject.getString("idCardNo"));
            dataCenterPushClueBo.setMobile(cusObject.getString("phoneno"));
        }else {
            throw new RuntimeException("小宝获取明文报错");
        }
        return dataCenterPushClueBo;
    }
}
